@@ -1,4 +1,4 @@
-__version__ = "0.1.1"
+__version__ = "0.1.3"
 
 import copy
 import datetime
@@ -6,7 +6,7 @@ import itertools
 import math
 import random
 from collections import Counter
-from typing import Tuple
+from typing import Tuple, Any
 
 import matplotlib.pyplot as plt
 import networkx as nx
@@ -33,11 +33,11 @@ def _fitness_function_factory(graph: nx.Graph):
     :return: fitness_function
     """
 
-    def _fitness_function(solution: tuple, solution_idx):
+    def _fitness_function(solution: tuple, solution_idx: Any):
         """
         Fitness function to measure the quality of a given chromosome, i.e., solution.
         :param solution: Chromosome: tuple with length equal to number of vertices. Each item, i.e., gen is a color
-        :param solution_idx:
+        :param solution_idx: Required by PyGAD interface but is not used
         :return: fitness: 1 - (Degree of Total Incompatibility (DTI))
         """
         return _get_coloring_score(graph, solution)
@@ -262,7 +262,7 @@ def greedy_k_color(graph: nx.Graph, k: int, fair: bool = False) -> dict:
         for u in nodes:
             # Set to keep track of colors of neighbours
             neighbour_colors = {coloring[v] for v in graph[u] if v in coloring}
-            for color in dict(sorted(available_colors.items(), key=lambda item: item[1])).keys():
+            for color in dict(sorted(available_colors.items(), key=lambda item: item[1])):
                 if color not in neighbour_colors:
                     available_colors[color] = available_colors[color] + 1
                     break
